# Define required providers
terraform {
  required_version = ">= 0.14.0"
  required_providers {
    openstack = {
      source  = "terraform-provider-openstack/openstack"
      version = "~> 1.53.0"
    }
  }
}

data "terraform_remote_state" "privnet_dns_router" {
  backend = "local"

  config = {
    path = "../project-setup/terraform.tfstate"
  }
}

#
# Uses common_variables as module
#
module "common_variables" {
  source = "../../modules/common_variables"
}


module "instance_with_data_volume" {
  source = "../../modules/instance_with_data_volume"

  instances_with_data_volume_map = {
    geoserver_geona = {
      name              = "geoserver-geona",
      description       = "Geoserver geona instance",
      flavor            = module.common_variables.flavor_list.m1_large,
      networks          = [data.terraform_remote_state.privnet_dns_router.outputs.main_private_network.name, module.common_variables.networks_list.shared_postgresql],
      security_groups   = [data.terraform_remote_state.privnet_dns_router.outputs.default_security_group_name, data.terraform_remote_state.privnet_dns_router.outputs.security_group_list.http_and_https_from_the_load_balancers],
      server_groups_ids = [],
      image_ref         = module.common_variables.ubuntu_1804,
      volume = {
        name   = "geoserver_geona_data_volume",
        size   = "50",
        device = "/dev/vdb"
      }
    },
    geoserver_esquiline = {
      name              = "geoserver-esquiline",
      description       = "Geoserver esquiline instance",
      flavor            = module.common_variables.flavor_list.m2_small,
      networks          = [data.terraform_remote_state.privnet_dns_router.outputs.main_private_network.name, module.common_variables.networks_list.shared_postgresql],
      security_groups   = [data.terraform_remote_state.privnet_dns_router.outputs.default_security_group_name, data.terraform_remote_state.privnet_dns_router.outputs.security_group_list.http_and_https_from_the_load_balancers],
      server_groups_ids = [],
      image_ref         = module.common_variables.ubuntu_1804,
      volume = {
        name   = "geoserver_esquiline_data_volume",
        size   = "20",
        device = "/dev/vdb",
      }
    },
    geoserver_ariadne = {
      name              = "geoserver-ariadne",
      description       = "Geoserver ariadne instance",
      flavor            = module.common_variables.flavor_list.m2_small,
      networks          = [data.terraform_remote_state.privnet_dns_router.outputs.main_private_network.name, module.common_variables.networks_list.shared_postgresql],
      security_groups   = [data.terraform_remote_state.privnet_dns_router.outputs.default_security_group_name, data.terraform_remote_state.privnet_dns_router.outputs.security_group_list.http_and_https_from_the_load_balancers],
      server_groups_ids = [],
      image_ref         = module.common_variables.ubuntu_1804,
      volume = {
        name   = "geoserver_ariadne_data_volume",
        size   = "20",
        device = "/dev/vdb",
      }
    },
    geoserver_grsf = {
      name              = "geoserver-grsf",
      description       = "Geoserver grsf instance",
      flavor            = module.common_variables.flavor_list.m1_large,
      networks          = [data.terraform_remote_state.privnet_dns_router.outputs.main_private_network.name, module.common_variables.networks_list.shared_postgresql],
      security_groups   = [data.terraform_remote_state.privnet_dns_router.outputs.default_security_group_name, data.terraform_remote_state.privnet_dns_router.outputs.security_group_list.http_and_https_from_the_load_balancers],
      server_groups_ids = [],
      image_ref         = module.common_variables.ubuntu_1804
      volume = {
        name   = "geoserver_grsf_data_volume"
        size   = "40",
        device = "/dev/vdb",
      }
    },
    geoserver_protectedareaimpactmaps = {
      name              = "geoserver-protectedareaimpactmaps",
      description       = "Geoserver protectedareaimpactmaps instance",
      flavor            = module.common_variables.flavor_list.c1_large,
      networks          = [data.terraform_remote_state.privnet_dns_router.outputs.main_private_network.name, module.common_variables.networks_list.shared_postgresql],
      security_groups   = [data.terraform_remote_state.privnet_dns_router.outputs.default_security_group_name, data.terraform_remote_state.privnet_dns_router.outputs.security_group_list.http_and_https_from_the_load_balancers],
      server_groups_ids = [],
      image_ref         = module.common_variables.ubuntu_1804,
      volume = {
        name   = "geoserver_protectedareaimpactmaps_data_volume"
        size   = "70",
        device = "/dev/vdb",
      }
    },
    geoserver_sdilab = {
      name              = "geoserver-sdilab",
      description       = "Geoserver sdilab instance",
      flavor            = module.common_variables.flavor_list.m1_large,
      networks          = [data.terraform_remote_state.privnet_dns_router.outputs.main_private_network.name, module.common_variables.networks_list.shared_postgresql],
      security_groups   = [data.terraform_remote_state.privnet_dns_router.outputs.default_security_group_name, data.terraform_remote_state.privnet_dns_router.outputs.security_group_list.http_and_https_from_the_load_balancers],
      server_groups_ids = [],
      image_ref         = module.common_variables.ubuntu_1804,
      volume = {
        name   = "geoserver_sdilab_data_volume",
        size   = "100",
        device = "/dev/vdb",
      }
    },
    geoserver_tunaatlas = {
      name              = "geoserver-tunaatlas",
      description       = "Geoserver tunaatlas instance",
      flavor            = module.common_variables.flavor_list.m1_large,
      networks          = [data.terraform_remote_state.privnet_dns_router.outputs.main_private_network.name, module.common_variables.networks_list.shared_postgresql],
      security_groups   = [data.terraform_remote_state.privnet_dns_router.outputs.default_security_group_name, data.terraform_remote_state.privnet_dns_router.outputs.security_group_list.http_and_https_from_the_load_balancers],
      server_groups_ids = [],
      image_ref         = module.common_variables.ubuntu_1804,
      volume = {
        name   = "geoserver_tunaatlas_data_volume",
        size   = "60",
        device = "/dev/vdb",
      }
    },
    geoserver_wecafcfirms = {
      name              = "geoserver-wecafcfirms",
      description       = "Geoserver wecafcfirms instance",
      flavor            = module.common_variables.flavor_list.m1_large,
      networks          = [data.terraform_remote_state.privnet_dns_router.outputs.main_private_network.name, module.common_variables.networks_list.shared_postgresql],
      security_groups   = [data.terraform_remote_state.privnet_dns_router.outputs.default_security_group_name, data.terraform_remote_state.privnet_dns_router.outputs.security_group_list.http_and_https_from_the_load_balancers],
      server_groups_ids = [],
      image_ref         = module.common_variables.ubuntu_1804,
      volume = {
        name   = "geoserver_wecafcfirms_data_volume",
        size   = "40",
        device = "/dev/vdb",
      }
    },
    geoserver_aquacultureatlas = {
      name              = "geoserver-aquacultureatlas",
      description       = "Geoserver aquacultureatlas instance",
      flavor            = module.common_variables.flavor_list.m1_large,
      networks          = [data.terraform_remote_state.privnet_dns_router.outputs.main_private_network.name, module.common_variables.networks_list.shared_postgresql],
      security_groups   = [data.terraform_remote_state.privnet_dns_router.outputs.default_security_group_name, data.terraform_remote_state.privnet_dns_router.outputs.security_group_list.http_and_https_from_the_load_balancers],
      server_groups_ids = [],
      image_ref         = module.common_variables.ubuntu_1804,
      volume = {
        name   = "geoserver_aquacultureatlas_data_volume",
        size   = "50",
        device = "/dev/vdb",
      }
    },
    geoserver_globalfisheriesatlas = {
      name              = "geoserver-globalfisheriesatlas",
      description       = "Geoserver globalfisheriesatlas instance",
      flavor            = module.common_variables.flavor_list.m1_large,
      networks          = [data.terraform_remote_state.privnet_dns_router.outputs.main_private_network.name, module.common_variables.networks_list.shared_postgresql],
      security_groups   = [data.terraform_remote_state.privnet_dns_router.outputs.default_security_group_name, data.terraform_remote_state.privnet_dns_router.outputs.security_group_list.http_and_https_from_the_load_balancers],
      server_groups_ids = [],
      image_ref         = module.common_variables.ubuntu_1804,
      volume = {
        name   = "geoserver_globalfisheriesatlas_data_volume",
        size   = "50",
        device = "/dev/vdb",
      }
    },
    geoserver_marineenvironmentalindicators = {
      name              = "geoserver-marineenvironmentalindicators",
      description       = "Geoserver marineenvironmentalindicators instance",
      flavor            = module.common_variables.flavor_list.m1_large,
      networks          = [data.terraform_remote_state.privnet_dns_router.outputs.main_private_network.name, module.common_variables.networks_list.shared_postgresql],
      security_groups   = [data.terraform_remote_state.privnet_dns_router.outputs.default_security_group_name, data.terraform_remote_state.privnet_dns_router.outputs.security_group_list.http_and_https_from_the_load_balancers],
      server_groups_ids = [],
      image_ref         = module.common_variables.ubuntu_1804,
      volume = {
        name   = "geoserver_marineenvironmentalindicators_data_volume",
        size   = "50",
        device = "/dev/vdb",
      }
    }
  }
}
